@@ -1,4 +1,4 @@
-/* $Id: thunar-vfs-exec.c 26393 2007-11-28 17:32:00Z benny $ */
+/* $Id: thunar-vfs-exec.c 26432 2007-12-03 17:50:17Z benny $ */
 /*-
  * Copyright (c) 2005-2007 Benedikt Meurer <benny@xfce.org>
  *
@@ -324,8 +324,10 @@ tvsn_startup_timeout_destroy (gpointer data)
   if (startup_data->watch_id != 0)
     g_source_remove (startup_data->watch_id);
 
-  /* close the PID */
-  g_spawn_close_pid (startup_data->pid);
+  /* make sure we don't leave zombies (see bug #2983 for details) */
+  g_child_watch_add_full (G_PRIORITY_LOW, startup_data->pid,
+                          (GChildWatchFunc) g_spawn_close_pid,
+                          NULL, NULL);
 
   /* release the startup data */
   _thunar_vfs_slice_free (TvsnStartupData, startup_data);
@@ -513,6 +515,12 @@ thunar_vfs_exec_on_screen (GdkScreen   *screen,
           startup_data->pid = pid;
         }
     }
+  else if (G_LIKELY (succeed))
+    {
+      /* make sure we don't leave zombies (see bug #2983 for details) */
+      g_child_watch_add_full (G_PRIORITY_LOW, pid, (GChildWatchFunc) g_spawn_close_pid, NULL, NULL);
+
+    }
 
   /* release the sn display */
   if (G_LIKELY (sn_display != NULL))
